#/bin/bash
# Part 1 of Datalad training material
set -eu -o pipefail

# Initialize paths
source env-paths


##### Create datasets #####
# create the study dataset
datalad create --cfg-proc text2git $study_dir
cd $study_dir

# create subdirectories
mkdir code
mkdir patient_1 patient_2

# create patient 1 with subdirectories and subdataset
cd $study_dir/patient_1
datalad create --dataset .. --cfg-proc text2git inputs
mkdir outputs_01_statistics

# create patient 2 with subdirectories and subdataset
cd $study_dir/patient_2
datalad create --dataset .. --cfg-proc text2git inputs
mkdir outputs_01_statistics

# add dataset description
cp $SRC_DIR/dataset_description.json $study_dir

# show subdatasets
cd $study_dir
datalad subdatasets


##### populate data in datasets #####
sh $SRC_DIR/create_data_patient1.sh $study_dir/patient_1/inputs
sh $SRC_DIR/create_data_patient2.sh $study_dir/patient_2/inputs


##### Datalad save/status and provenance history (commit log) #####
cd $study_dir

# show superdataset status
datalad status
datalad save --message "Add description file"
datalad status

cd $study_dir/patient_1/inputs
# show patient 1 inputs dataset status
datalad status
# save patient 1 data
datalad save --message "Add raw data"
# The message of the most recent commit maybe amended with 'git commit --amend'
# This is useful when the message was not added initially, or needs to be changed

# show updated patient 1 inputs dataset status
datalad status
# show history of actions
git log
# show modification in last commit
# git log -1 --stat
# other log options:
# git log -p  # see changes
# git log  # see everything
# git log --oneline  # concise listing

# save patient 2 data
cd $study_dir/patient_2/inputs
datalad save --message "Add raw data"

# show superdataset status
cd $study_dir
datalad status

# save subdataset changes to superdataset
datalad save --message "Update subdatasets"

# add code
cp $SRC_DIR/stats.py $study_dir/code
cp $SRC_DIR/aggregate.py $study_dir/code

# recursively save datasets in a single command
cd $study_dir
datalad save --message "Add code"


##### git revert #####
# git revert -e <commit>

##### Add a binary file and save recursively #####
cd $study_dir
head -c 1000 /dev/urandom > patient_1/inputs/file.bin
datalad save --recursive --message "Add binary file"
ls -ltrh patient_1/inputs/file.bin


##### file unlocking #####
# Unlocking an annex'ed file permits its modification
# if no changes are to be done, lock the file
# otherwise, save the changes via datalad save
cd $study_dir/patient_1/inputs
datalad unlock file.bin
git annex lock file.bin

##### Remove dataset #####
#datalad remove -d $study_dir --reckless kill

# End of part 1
